timeintervaltools.scale_aggregate_duration_by_rational
======================================================

.. autofunction:: abjad.tools.timeintervaltools.scale_aggregate_duration_by_rational.scale_aggregate_duration_by_rational
   :noindex:
